| plot_latent | R Documentation |
Shows the posterior median of the latent state (log-rate for the Poisson family, logit for the binomial family, one additive-log-ratio series per non-baseline category for the multinomial family) with a credible band.
plot_latent(object, level = 0.95, category = NULL, ...)
object |
A |
level |
Credible level for the band. Default |
category |
Multinomial family only: which categories to draw (names
or indices among the non-baseline categories for |
... |
Passed to |
Invisibly, the summary data frame used for plotting (in long format
with a category column for the multinomial family).
sim <- simulate_dynamic_poisson(60, 0.2, 2, seed = 1)
fit <- fit_dynamic_model(sim$y, nsave = 300, nburn = 200, seed = 1)
plot_latent(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.